..
      Copyright 2018 Catalyst IT Ltd
      All Rights Reserved.
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Security Considerations
=======================

This guide talks about the security considerations from the system administrator's perspective, how
to avoid to be affected by the "bad" function that the end user provides.

Kubernetes
~~~~~~~~~~

Service account
---------------

Inter-Pods communication
------------------------
